@@ -2,6 +2,7 @@ from typing import Optional
 
 from graphql import ResolveInfo
 
+from jnt_django_graphene_toolbox.errors import GraphQLPermissionDenied
 from jnt_django_graphene_toolbox.security.permissions import AllowAuthenticated
 
 
@@ -24,3 +25,14 @@ class AuthMutation:
                 for perm in cls.permission_classes
             ),
         )
+
+    @classmethod
+    def check_premissions(
+        cls,
+        root: Optional[object],
+        info: ResolveInfo,  # noqa: WPS110
+        **input,  # noqa: WPS125
+    ) -> None:
+        """Check permissions."""
+        if not cls.has_permission(root, info, **input):
+            raise GraphQLPermissionDenied
